@@ -8,11 +8,15 @@ from django.core.exceptions import ValidationError
 from django.core.validators import MaxValueValidator
 from django.core.validators import MinValueValidator
 from django.db import models
-from django.utils.datastructures import SortedDict
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
-from .utils import cached_property
 from .utils import PY3
+from .utils import cached_property
+
+try:
+    from django.utils.datastructures import SortedDict as OrderedDict
+except ImportError:
+    from collections import OrderedDict
 
 REDISBOARD_DETAIL_FILTERS = [re.compile(name) for name in getattr(settings, 'REDISBOARD_DETAIL_FILTERS', (
     'aof_enabled', 'bgrewriteaof_in_progress', 'bgsave_in_progress',
@@ -29,6 +33,11 @@ REDISBOARD_DETAIL_SECONDS_KEYS = getattr(settings, 'REDISBOARD_DETAIL_SECONDS_KE
 
 REDISBOARD_SLOWLOG_LEN = getattr(settings, 'REDISBOARD_SLOWLOG_LEN', 10)
 
+REDISBOARD_SOCKET_TIMEOUT = getattr(settings, 'REDISBOARD_SOCKET_TIMEOUT', None)
+REDISBOARD_SOCKET_CONNECT_TIMEOUT = getattr(settings, 'REDISBOARD_SOCKET_CONNECT_TIMEOUT', None)
+REDISBOARD_SOCKET_KEEPALIVE = getattr(settings, 'REDISBOARD_SOCKET_KEEPALIVE', None)
+REDISBOARD_SOCKET_KEEPALIVE_OPTIONS = getattr(settings, 'REDISBOARD_SOCKET_KEEPALIVE_OPTIONS', None)
+
 
 def prettify(key, value):
     if key in REDISBOARD_DETAIL_SECONDS_KEYS:
@@ -95,6 +104,10 @@ class RedisServer(models.Model):
             port=self.port,
             password=self.password,
             unix_socket_path=unix_socket_path,
+            socket_timeout=REDISBOARD_SOCKET_TIMEOUT,
+            socket_connect_timeout=REDISBOARD_SOCKET_CONNECT_TIMEOUT,
+            socket_keepalive=REDISBOARD_SOCKET_KEEPALIVE,
+            socket_keepalive_options=REDISBOARD_SOCKET_KEEPALIVE_OPTIONS,
         )
 
     @connection.deleter
@@ -104,7 +117,10 @@ class RedisServer(models.Model):
     @cached_property
     def stats(self):
         try:
-            info = self.connection.info()
+            conn = self.connection
+            info = conn.info()
+            slowlog = conn.slowlog_get()
+            slowlog_len = conn.slowlog_len()
             return {
                 'status': 'UP',
                 'details': info,
@@ -113,12 +129,14 @@ class RedisServer(models.Model):
                     info.get('used_memory_peak_human', 'n/a')
                 ),
                 'clients': info['connected_clients'],
-                'brief_details': SortedDict(
+                'brief_details': OrderedDict(
                     prettify(k, v)
                     for name in REDISBOARD_DETAIL_FILTERS
                     for k, v in (info.items() if PY3 else info.iteritems())
                     if name.match(k)
-                )
+                ),
+                'slowlog': slowlog,
+                'slowlog_len': slowlog_len,
             }
         except redis.exceptions.ConnectionError:
             return {
@@ -127,6 +145,8 @@ class RedisServer(models.Model):
                 'memory': 'n/a',
                 'details': {},
                 'brief_details': {},
+                'slowlog': [],
+                'slowlog_len': 0,
             }
         except redis.exceptions.ResponseError as exc:
             return {
@@ -135,6 +155,8 @@ class RedisServer(models.Model):
                 'memory': 'n/a',
                 'details': {},
                 'brief_details': {},
+                'slowlog': [],
+                'slowlog_len': 0,
             }
 
     def __unicode__(self):
@@ -158,13 +180,12 @@ class RedisServer(models.Model):
 
     def slowlog_get(self, limit=REDISBOARD_SLOWLOG_LEN):
         try:
-            slowlog_get = self.connection.slowlog_get(REDISBOARD_SLOWLOG_LEN)
-            for i, (id, ts, duration, command) in enumerate(slowlog_get):
+            for slowlog in self.connection.slowlog_get(REDISBOARD_SLOWLOG_LEN):
                 yield dict(
-                    id=id,
-                    ts=datetime.fromtimestamp(ts),
-                    duration=duration,
-                    command=command,
+                    id=slowlog['id'],
+                    ts=datetime.fromtimestamp(slowlog['start_time']),
+                    duration=slowlog['duration'],
+                    command=slowlog['command'],
                 )
 
         except redis.exceptions.ConnectionError:
