@@ -1,4 +1,8 @@
 # shamelessly taken from kombu.utils
+import sys
+
+PY3 = sys.version_info[0] == 3
+
 
 class LazySlicingIterable(object):
     def __init__(self, length_getter, items_getter):
@@ -18,6 +22,7 @@ class LazySlicingIterable(object):
         else:
             raise TypeError("Must be int or slice.")
 
+
 class cached_property(object):
     """Property descriptor that caches the return value
     of the get function.
